@@ -19,8 +19,10 @@
 #
 import inspect
 import socket
+import threading
 import time
 import warnings
+import weakref
 import zmq
 
 from kitchen.text.converters import to_utf8
@@ -57,7 +59,8 @@ class FedMsgContext(object):
         # If no name is provided, use the calling module's __name__ to decide
         # which publishing endpoint to use.
         if not config.get("name", None):
-            config["name"] = self.guess_calling_module() + '.' + self.hostname
+            module_name = self.guess_calling_module(default="fedmsg")
+            config["name"] = module_name + '.' + self.hostname
 
             if any(map(config["name"].startswith, ['fedmsg'])):
                 config["name"] = None
@@ -118,15 +121,14 @@ class FedMsgContext(object):
         else:
             warnings.warn("fedmsg is not configured to send any messages")
 
+        # Cleanup.  See http://bit.ly/SaGeOr for discussion.
+        weakref.ref(threading.current_thread(), self.destroy)
+
         # Sleep just to make sure that the socket gets set up before anyone
         # tries anything.  This is a documented zmq 'feature'.
         time.sleep(config['post_init_sleep'])
 
     def destroy(self):
-        self.__del__()
-
-    def __del__(self):
-        """ Destructor """
         if getattr(self, 'publisher', None):
             self.publisher.close()
             self.publisher = None
@@ -139,15 +141,15 @@ class FedMsgContext(object):
         raise NotImplementedError
 
     # TODO -- this should be in kitchen, not fedmsg
-    def guess_calling_module(self):
+    def guess_calling_module(self, default=None):
         # Iterate up the call-stack and return the first new top-level module
         for frame in (f[0] for f in inspect.stack()):
             modname = frame.f_globals['__name__'].split('.')[0]
             if modname != "fedmsg":
                 return modname
 
-        # Otherwise, give up and just return our own module name.
-        return "fedmsg"
+        # Otherwise, give up and just return the default.
+        return default
 
     def send_message(self, topic=None, msg=None, modname=None):
         warnings.warn(".send_message is deprecated.",
@@ -166,7 +168,7 @@ class FedMsgContext(object):
             return
 
         # If no modname is supplied, then guess it from the call stack.
-        modname = modname or self.guess_calling_module()
+        modname = modname or self.guess_calling_module(default="fedmsg")
         topic = '.'.join([modname, topic])
 
         if topic[:len(self.c['topic_prefix'])] != self.c['topic_prefix']:
